@@ -13,7 +13,7 @@ def _loss_names(d):
         "mtp": 0,  # mof topology prediction
         "vfp": 0,  # (accessible) void fraction prediction
         "moc": 0,  # metal organic classification
-        "bbp": 0,  # building block prediction
+        "bbc": 0,  # building block classification
         "classification": 0,  # classification
         "regression": 0,  # regression
     }
@@ -25,7 +25,7 @@ def _loss_names(d):
 def config():
     """
     # prepare_data
-    max_num_atoms = 1000
+    max_num_atoms = 300
     min_length = 30
     max_length = 60
     radius = 8
@@ -35,7 +35,7 @@ def config():
     # model
     exp_name = "pretrained_mof"
     seed = 0
-    loss_names = _loss_names({"regression":1})
+    loss_names = _loss_names({"regression": 1})
 
     # graph seeting
     # max_atom_len = 1000  # number of maximum atoms in primitive cell
@@ -84,7 +84,7 @@ def config():
     log_dir = "logs/"
     batch_size = 1024  # desired batch size; for gradient accumulation
     per_gpu_batchsize = 8  # you should define this manually with per_gpu_batch_size
-    accelerator='gpu'
+    accelerator = 'gpu'
     devices = 1
     num_nodes = 1
 
@@ -114,108 +114,21 @@ def example():
 
 
 @ex.named_config
-def ppn_1bar():
-    exp_name = "ppn_1bar"
-    root_dataset = "transfer_learning/2_insilico_ppn/dataset"
-    downstream = "1bar"
+def test():
+    exp_name = "example"
+    loss_names = _loss_names({"regression": 0})
+    root_dataset = "moftransformer/examples/dataset"
+    downstream = "example"
     max_epochs = 20
     batch_size = 32
-    mean = 3.79
-    std = 5.32
+
 
 @ex.named_config
-def ppn_65bar():
-    exp_name = "ppn_65bar"
-    root_dataset = "transfer_learning/2_insilico_ppn/dataset"
-    downstream = "65bar"
+def total_h2_uptake():
+    exp_name = "total_h2_uptake"
+    # root_dataset = ##
+    downstream = "h2_uptake"
     max_epochs = 20
     batch_size = 32
-    mean = 117.78
-    std = 30.75
-
-"""
-in silico COF
-"""
-@ex.named_config
-def cof_lowbar_scratch():
-    load_path = ""
-    exp_name = "cof_lowbar_scratch"
-    root_dataset = "transfer_learning/4_insilico_cof/dataset"
-    downstream = "lowbar"
-    max_epochs = 20
-    batch_size = 32
-    mean = 23.750
-    std = 17.166
-
-@ex.named_config
-def cof_lowbar():
-    exp_name = "cof_lowbar"
-    root_dataset = "transfer_learning/4_insilico_cof/dataset"
-    downstream = "lowbar"
-    max_epochs = 20
-    batch_size = 32
-    mean = 23.750
-    std = 17.166
-
-@ex.named_config
-def cof_highbar_scratch():
-    load_path = ""
-    exp_name = "cof_highbar_scratch"
-    root_dataset = "transfer_learning/4_insilico_cof/dataset"
-    downstream = "highbar"
-    max_epochs = 20
-    batch_size = 32
-    mean = 159.076
-    std = 38.164
-
-@ex.named_config
-def cof_highbar():
-    exp_name = "cof_highbar"
-    root_dataset = "transfer_learning/4_insilico_cof/dataset"
-    downstream = "highbar"
-    max_epochs = 20
-    batch_size = 32
-    mean = 159.076
-    std = 38.164
-
-@ex.named_config
-def cof_logkh_scratch():
-    load_path = ""
-    exp_name = "cof_logkh_scratch"
-    root_dataset = "transfer_learning/4_insilico_cof/dataset"
-    downstream = "logkh"
-    max_epochs = 20
-    batch_size = 32
-    mean = -10.975
-    std = 0.563
-
-@ex.named_config
-def cof_logkh():
-    exp_name = "cof_logkh"
-    root_dataset = "transfer_learning/4_insilico_cof/dataset"
-    downstream = "logkh"
-    max_epochs = 20
-    batch_size = 32
-    mean = -10.975
-    std = 0.563
-
-@ex.named_config
-def cof_qst_scratch():
-    load_path = ""
-    exp_name = "cof_qst_scratch"
-    root_dataset = "transfer_learning/4_insilico_cof/dataset"
-    downstream = "qst"
-    max_epochs = 20
-    batch_size = 32
-    mean = -14.793
-    std = 4.542
-
-@ex.named_config
-def cof_qst():
-    exp_name = "cof_qst"
-    root_dataset = "transfer_learning/4_insilico_cof/dataset"
-    downstream = "qst"
-    max_epochs = 20
-    batch_size = 32
-    mean = -14.793
-    std = 4.542
\ No newline at end of file
+    mean = 423.251
+    std = 136.293
