@@ -48,7 +48,7 @@ class Dataset(torch.utils.data.Dataset):
         self.tasks = {}
 
         for task in tasks:
-            if task in ["mtp", "vfp", "moc", "bbp"]:
+            if task in ["mtp", "vfp", "moc", "bbc"]:
                 path_file = os.path.join(data_dir, f"{split}_{task}.json")
                 print(f"read {path_file}...")
                 assert os.path.isfile(path_file), f"{path_file} doesn't exist in {data_dir}"
@@ -149,7 +149,7 @@ class Dataset(torch.utils.data.Dataset):
         file_graph = os.path.join(self.data_dir, self.split, f"{cif_id}.graphdata")
 
         graphdata = pickle.load(open(file_graph, "rb"))
-        # graphdata = ["cif_id", "atom_num", "nbr_idx", "nbr_dist", "uni_idx", "uni_count", "target"]
+        # graphdata = ["cif_id", "atom_num", "nbr_idx", "nbr_dist", "uni_idx", "uni_count"]
         atom_num = torch.LongTensor(graphdata[1].copy())
         nbr_idx = torch.LongTensor(graphdata[2].copy()).view(len(atom_num), -1)
         nbr_dist = torch.FloatTensor(graphdata[3].copy()).view(len(atom_num), -1)
@@ -239,13 +239,17 @@ class Dataset(torch.utils.data.Dataset):
         batch_grid_data = dict_batch["grid_data"]
         batch_cell = dict_batch["cell"]
         new_grids = []
+
         for bi in range(batch_size):
             orig = batch_grid_data[bi].view(batch_cell[bi][::-1]).transpose(0, 2)
-            orig = interpolate(orig[None, None, :, :, :],
-                               size=[img_size, img_size, img_size],
-                               mode="trilinear",
-                               align_corners=True,
-                               )
+            if batch_cell[bi] == [30, 30, 30]:      # version >= 1.1.2
+                orig = orig[None, None, :, :, :]
+            else:
+                orig = interpolate(orig[None, None, :, :, :],
+                                   size=[img_size, img_size, img_size],
+                                   mode="trilinear",
+                                   align_corners=True,
+                                   )
             new_grids.append(orig)
         new_grids = torch.concat(new_grids, axis=0)
         dict_batch["grid"] = new_grids
@@ -257,11 +261,14 @@ class Dataset(torch.utils.data.Dataset):
             new_false_grids = []
             for bi in range(batch_size):
                 orig = batch_false_grid_data[bi].view(batch_false_cell[bi])
-                orig = interpolate(orig[None, None, :, :, :],
-                                   size=[img_size, img_size, img_size],
-                                   mode="trilinear",
-                                   align_corners=True,
-                                   )
+                if batch_cell[bi] == [30, 30, 30]:  # version >= 1.1.2
+                    orig = orig[None, None, :, :, :]
+                else:
+                    orig = interpolate(orig[None, None, :, :, :],
+                                       size=[img_size, img_size, img_size],
+                                       mode="trilinear",
+                                       align_corners=True,
+                                       )
                 new_false_grids.append(orig)
             new_false_grids = torch.concat(new_false_grids, axis=0)
             dict_batch["false_grid"] = new_false_grids
